# ingroupchina.R
# Replication script for balance tables and figures in:
# Ingroup Bias in Official Behavior: A National Field Experiment in China
# Greg Distelhorst and Yue Hou

library(lmtest)
library(sandwich)
library(foreign)
library(Matching)
library(ebal)
library(apsrtable)
library(lattice)

# ADJUST WORKING DIRECTORY FOR YOUR OWN SETUP
setwd("D:/Dropbox/_MIT/GMD-YH/analysis/replication") 

# Chinese language locale no longer required
# Sys.setlocale(category = "LC_ALL", locale = "chs")

rm(list=ls())
xx = read.dta("ingroup_replication.dta")

# qw() -  turns unquoted barewords into vector of strings
# qw(a, b) --> "a" "b"
qw <- function(...) {
  sapply(match.call()[-1], deparse)
}

# returns a count of NAs in x
count.na = function(x) {
  return(length(which(is.na(x)))) 
}
          
#############################################
# TABLE B1: PRETREATMENT COVARIATE BALANCE

# adjust the units so they make sense
# area  LandArea (sq.km) -- OK
# pop  TotalPopulation(yearend)(10000persons)
xx$pop = xx$pop/100 # pop in millions
# grp	GrossRegionalProduct(100millionyuan)
xx$grp = xx$grp/10 # grp in billion RMB
# primary, secondary, tertiary in %-- OK
# govrev	GeneralBugetaryRevenue(100millionyuan)
xx$govrev = xx$govrev / 10 # revenue in billion RMB
# govexp	GeneralBugetaryExpenditure(100millionyuan)
xx$govexp = xx$govexp / 10 # expenditure in billion RMB
# imports	Imports (USD 10000)
xx$imports = xx$imports / 100 # imports and exports in million USD
xx$exports = xx$exports / 100 
# fdi	TotalAmountofForeignDirectInvestmentActuallyUtilized(USD10000)
xx$fdi = xx$fdi / 100 # FDI in million USD

# Three indicators for previous responsiveness of mailbox in June 2012
xx$junerep = xx$june   
xx$june_tenplus = 0
xx$june_tenplus[xx$junerep==3] = 1
xx$june_onetoten = 0
xx$june_onetoten[xx$junerep==2] = 1
xx$june_none = 0
xx$june_none[xx$junerep==1] = 1


# Descriptive names of pre-treatment covariates
covnames = c("Area (sq km)", 
             "Population (million)", 
             "GDP (billion RMB)", 
             "per capita GDP (RMB)", 
             "Primary GDP (\\%)", "Secondary GDP (\\%)", "Tertiary GDP (\\%)", 
             "Govt revenue (billion RMB)", 
             "Govt spending (billion RMB)", 
             "Imports (million USD)", 
             "Exports (million USD)", 
             "FDI (million USD)", 
             "$>$10 replies (\\%)", "1-10 replies (\\%)", "No replies (\\%)", 
             "SubmissionDate", "Ethnic conflict")

covnames.eth = c("Han (\\%)", "Hui (\\%)", "Uighur (\\%)", "Muslim (\\%)")

covindex = qw(area, pop, grp, pcgrp, primary, secondary, tertiary, govrev, govexp, imports, exports, fdi, june_tenplus, june_onetoten, june_none, submit_date_num, conflict)

covindex.eth = qw(pcthan, pcthui, pctuighur, pctmuslim)

# Which covariates missing?  
apply(xx[xx$submitted==1,c(covindex,covindex.eth)], MARGIN=2, count.na)

# To avoid listwise deletion of 3 prefs with no ethnic demographics, separate main balance check from ethnic balance check

# Check balance on submitted requests (non-ethnic)
# Note that KS estimates are slightly unstable even at 10k bootstraps
# KS pvals may vary on the order of a few hundredths
mb.submit = MatchBalance(tr ~ area + pop + grp + pcgrp + primary + secondary + tertiary + govrev + govexp + imports + exports + fdi + june_tenplus + june_onetoten + june_none + submit_date_num + conflict, data=xx[xx$submitted==1,], ks=T, nboots=10000)
btest.submit = baltest.collect(mb.submit, covnames, after=F)
btest.submit
submit.balance = cbind(round(btest.submit[,1:2],3),round(btest.submit[,6:7],2))
submit.balance = rbind(c(128,130,NA,NA),submit.balance)
rownames(submit.balance) = c("N", covnames)
submit.balance

# Check ethnic demographic balance
mb.submit.eth = MatchBalance(tr ~ pcthan +  pcthui + pctuighur + pctmuslim, data=xx[xx$submitted==1,], ks=T, nboots=10000)
btest.submit.eth = baltest.collect(mb.submit.eth, covnames.eth, after=F)
submit.balance.eth = cbind(round(btest.submit.eth[,1:2],3),round(btest.submit.eth[,6:7],2))
submit.balance.eth

# Merge tables
balance.final = rbind(submit.balance[1:13,],submit.balance.eth,submit.balance[14:18,])
balance.final

# Latex table format
write.table(balance.final, sep=" & ", eol=" \\\\\n", quote=F)

##################################################
# TABLE C1: CONTACTED AND UNREACHABLE PREFECTURES

# Check missing for entire dataset: 5 with missing ethnicity data
apply(xx[,covindex], MARGIN=2, count.na)

# To avoid listwise deletion of 5 prefs with no ethnic demographics, separate main balance check from ethnic balance check

covnames.all = c(covnames[1:15], covnames[17])
covnames.all
mb.all = MatchBalance(submitted ~ area + pop + grp + pcgrp + primary + secondary + tertiary + govrev + govexp + imports + exports + fdi +  june_tenplus + june_onetoten + june_none + conflict, data=xx, ks=T)
btest.all = baltest.collect(mb.all, covnames.all, after=F, nboots=10000)
btest.all
all.balance = cbind(round(btest.all[,1:2],2),round(btest.all[,6:7],2))
all.balance = rbind(c(258,78,NA,NA),all.balance)
rownames(all.balance) = c("N", covnames.all)
all.balance.out = all.balance[,1:3]
all.balance.out

# Check balance on ethnic demographics separately
mb.all.eth = MatchBalance(submitted ~ pcthan +  pcthui + pctuighur + pctmuslim, data=xx, ks=T, nboots=10000)
btest.all.eth = baltest.collect(mb.all.eth, covnames.eth, after=F)
all.balance.eth = cbind(round(btest.all.eth[,1:2],3),round(btest.all.eth[,6:7],2))
all.balance.eth = all.balance.eth[,1:3]
all.balance.eth

# Merge tables
all.balance.final = rbind(all.balance.out, all.balance.eth)
all.balance.final

# Latex table format
write.table(all.balance.final, sep=" & ", eol=" \\\\\n", quote=F)





######################################################
# Figure 1
# Loess plots illustrating HTE by GRP and Muslim population

control = which(!is.na(xx$pctmuslim) & xx$submitted==1 & xx$tr==0)
treated = which(!is.na(xx$pctmuslim) & xx$submitted==1 & xx$tr==1)
#plot(log10(xx$pctmuslim[control]),xx$disc4wk[control])


# PLOTTING THE LOESS FITS WITH CI
# SETUP
control.color = "white"
tr.color = "black"
ci.color = "gray90"
cpoint.color = "gray"
se.lty = 1
main.lwd = 2
dotcex = .6
#xx$disc4wk = xx$disc4wk * 100
leg.inset=.045
leg.cex = 1
lcex = 1.3
boxtype = "o" # use "o" for full borders
filename = "loess_hte_box.pdf"
# For powerpoint
# tr.color="blue"

# Output file and panel parameters
pdf(filename, 4.25, 7.5)
par(mfrow=c(3,1), mgp=c(2.1,1,0), mar=c(4.1,4.1,2.1,2.1))


########################
# Panel 1: PCT MUSLIM
myseq = seq(-4,-.25,.05)
with(xx[control,], plot(log10(pctmuslim),disc4wk_100, pch=16, col=cpoint.color, cex=dotcex, xlab="Muslim population", ylab="Disclosure rate", xaxt="n", xlim=c(-4,0),bty=boxtype, cex.lab = lcex, cex.axis=lcex))
legend("top", inset=leg.inset, legend=c("Control","Muslim"), cex=leg.cex, fill=c(cpoint.color, tr.color),border=NA,ncol=1, bty="n")
#with(xx[treated,], points(log10(pctmuslim),disc4wk-2, pch=16, cex=dotcex, col=tr.color))

# CONTROL
lfit = loess(disc4wk_100~log10(pctmuslim), data=xx[control,])
plx = predict(lfit, newdata=myseq, se=T, na.action=no.omit)
polygon(c(myseq, rev(myseq)), c(plx$fit+2*plx$se, rev(plx$fit-2*plx$se)), col=ci.color, border=NA)
lines(myseq,plx$fit, col=control.color, lwd=main.lwd)
#lines(myseq,plx$fit+2*plx$se, lty=se.lty, col=control.color)
#lines(myseq,plx$fit-2*plx$se, lty=se.lty, col=control.color)

# TREATED 
lfit = loess(disc4wk_100~log10(pctmuslim), data=xx[treated,])
plx = predict(lfit, newdata=myseq, se=T, na.action=no.omit)
#polygon(c(myseq, rev(myseq)), c(plx$fit+2*plx$se, rev(plx$fit-2*plx$se)), col='gray80', border=NA)
lines(myseq,plx$fit, col=tr.color, lwd=main.lwd)
lines(myseq,plx$fit+2*plx$se, lty=se.lty, col=tr.color)
lines(myseq,plx$fit-2*plx$se, lty=se.lty, col=tr.color)
with(xx[control,], points(log10(pctmuslim),disc4wk_100, pch=16, col=cpoint.color, cex=dotcex))
with(xx[treated,], points(log10(pctmuslim),disc4wk_100-2, pch=16, cex=dotcex, col=tr.color))
axis(1, at=seq(-4,0), labels=c("0.01%", "0.1%", "1%", "10%", "100%"), cex.axis=lcex)

###################
# Panel 2: MUSLIM POPULATION COUNT
myseq = seq(2.5,5.6,.05)
with(xx[control,], plot(log10(muspop * 1000),disc4wk_100, pch=16, col=cpoint.color, cex=dotcex, xlab="Muslim population", ylab="Disclosure rate",xaxt="n", xlim=c(2.2,6),bty=boxtype, cex.lab = lcex, cex.axis=lcex))
legend("top", inset=leg.inset, legend=c("Control","Muslim"), cex=leg.cex, fill=c(cpoint.color, tr.color),border=NA,ncol=1, bty="n")
# with(xx[treated,], points(log10(muspop * 1000),disc4wk-2, pch=16, cex=dotcex, col=tr.color))

# CONTROL
lfit = loess(disc4wk_100~log10(muspop * 1000), data=xx[control,])
plx = predict(lfit, newdata=myseq, se=T, na.action=no.omit)
polygon(c(myseq, rev(myseq)), c(plx$fit+2*plx$se, rev(plx$fit-2*plx$se)), col=ci.color, border=NA)
lines(myseq,plx$fit, col=control.color, lwd=main.lwd)
#lines(myseq,plx$fit+2*plx$se, lty=se.lty, col=control.color)
#lines(myseq,plx$fit-2*plx$se, lty=se.lty, col=control.color)

# TREATED 
lfit = loess(disc4wk_100~log10(muspop * 1000), data=xx[treated,])
plx = predict(lfit, newdata=myseq, se=T, na.action=no.omit)
#polygon(c(myseq, rev(myseq)), c(plx$fit+2*plx$se, rev(plx$fit-2*plx$se)), col='gray80', border=NA)
lines(myseq,plx$fit, col=tr.color, lwd=main.lwd)
lines(myseq,plx$fit+2*plx$se, lty=se.lty, col=tr.color)
lines(myseq,plx$fit-2*plx$se, lty=se.lty, col=tr.color)
with(xx[control,], points(log10(muspop * 1000),disc4wk_100, pch=16, col=cpoint.color, cex=dotcex))
with(xx[treated,], points(log10(muspop * 1000),disc4wk_100-2, pch=16, cex=dotcex, col=tr.color))
axis(1, at=c(2,3,4,5,6), labels=c("100", "1,000", "10,000", "100,000", "1m"), cex.axis=lcex)

################################
# Panel 3: Per capita GDP (no log)
myseq=seq(6500, 40000, 500)
with(xx[control,], plot(pcgrp,disc4wk_100, pch=16, cex=dotcex, col=cpoint.color,xlab="Per capita GDP (RMB)", ylab="Disclosure rate", xlim=c(4000,41000),bty=boxtype, cex.lab = lcex, cex.axis=lcex))
legend("top", inset=leg.inset, legend=c("Control","Muslim"), cex=leg.cex, fill=c(cpoint.color, tr.color),border=NA,ncol=1, bty="n")
with(xx[treated,], points(pcgrp,disc4wk_100-2, pch=16, cex=dotcex, col=tr.color))

# CONTROL
lfit = loess(disc4wk_100~pcgrp, data=xx[control,])
plx = predict(lfit, newdata=myseq, se=T, na.action=no.omit)
polygon(c(myseq, rev(myseq)), c(plx$fit+2*plx$se, rev(plx$fit-2*plx$se)), col=ci.color, border=NA)
lines(myseq,plx$fit, col=control.color, lwd=main.lwd)

# TREATED 
lfit = loess(disc4wk_100~pcgrp, data=xx[treated,])
plx = predict(lfit, newdata=myseq, se=T, na.action=no.omit)
lines(myseq,plx$fit, col=tr.color, lwd=main.lwd)
lines(myseq,plx$fit+2*plx$se, lty=se.lty, col=tr.color)
lines(myseq,plx$fit-2*plx$se, lty=se.lty, col=tr.color)
with(xx[control,], points(pcgrp,disc4wk_100, pch=16, col=cpoint.color, cex=dotcex))
with(xx[treated,], points(pcgrp,disc4wk_100-2, pch=16, cex=dotcex, col=tr.color))

# Close output file
dev.off()


##########################################
# Figure B1: Map of contacted prefectures

library(ggmap); library(ggplot2);
library(maptools); library(gpclib); library(sp);
gpclibPermit()


# Get prefecture shapes
#prefshapes = load("ingroup_prefshapes.RData")
prefshapes = readShapeSpatial("ingroup_prefshapes.shp", proj4string = CRS("+proj=longlat +datum=WGS84"))

submitted.prefnums = xx$prefnum[xx$submitted==1]
nonsubmitted.prefnums = xx$prefnum[xx$submitted==0]

submitted.prefshapes = prefshapes[prefshapes$prefnum %in% submitted.prefnums,]
dim(submitted.prefshapes)

nonsubmitted.prefshapes = prefshapes[prefshapes$prefnum %in% nonsubmitted.prefnums,]
dim(nonsubmitted.prefshapes)


# Generate faded satellite map

# Create a China-sized box
bbox.china= bbox(prefshapes)
chinabox.x = c(bbox.china[1,1], bbox.china[1,1], bbox.china[1,2], bbox.china[1,2])
chinabox.y = c(bbox.china[2,1], bbox.china[2,2], bbox.china[2,2], bbox.china[2,1])
chinabox.poly = data.frame(cbind(chinabox.x, chinabox.y))

# Base layer: satellite map
china.satellite = get_map(location="China", zoom=3, maptype="satellite")
basemap = ggmap(china.satellite, extent = "device")

# Fade map using China box
map = basemap + geom_polygon(aes(x = chinabox.x, y=chinabox.y), data=chinabox.poly, fill="white", alpha = .5)

# Shade contacted, add prefecture borders
map = map + geom_polygon(aes(x = long, y = lat, group = group), alpha=.7, data =   submitted.prefshapes, fill="blue4") 
map = map + geom_path(aes(x = long, y = lat, group = group), data = prefshapes, color="blue4", size=.04)

# Preview
# map             
# dev.off()

# Export map
ggsave("contactedmap.pdf", map, height=3, width=3)

# Review tables
# Table B1: Pre-treatment covariate balance
balance.final

# Table C1: Contacted vs. unreachable prefectures
all.balance.final
